library(gtools)
library(stringr)
library(magrittr)
library(data.table)
library(tidyr)
library(mosaic)
library(ggpmisc)
library(dplyr)
library(Hmisc)
library(gmodels)
titel <- "OSER assay"
ondertitel1 <- 'Grown on glucose' #subtitle1
ondertitel2 <- 'Grown on room temperature, bars:95CI'                   #subtitle2
TextatXaxis <- ""   #which label should the X axis have?
TextatYaxix <- "" #which label should the y axis have?

#import data
wd <<- choose.dir()     #set input folder
setwd(wd)              #set input folder
filelist = list.files(pattern = "Results.*.txt")       #make a list with all the txtfiles in a folder
datalist = lapply(filelist, function(x)read.table(x, sep="\t", header=T)) 
combined = do.call("smartbind", datalist) 

#change names so you can better recognize each FP (sometimes capitals are not used for example)
combined$Label <- gsub("Cyterm-ymNeongreen", "Cyterm-ymneongreen", combined$Label)
combined$Label <- gsub("Cyterm-ymscarletI", "Cyterm-ymscarleti", combined$Label)

#change dataframe format
combined2 <- gather(combined, c(Label, Label2), Fluorescence, starts_with("Mean")) #change format of the dataframe 

#add FP
library(mosaic)
combined3 <- mutate(combined2, FP = derivedFactor(
  "ytdTomato" = str_detect(Label, "ytdtomato"),
  "dTomato" = str_detect(Label, "dtomato"),
  "ymvenus" = str_detect(Label, "mvenus"),
  "yeVenus" = str_detect(Label, "venus"),
  "ymNeongreen" = str_detect(Label, "ymneongreen"),
  "ymScarletI" = str_detect(Label, "ymscarleti"),
  "ymTq2" = str_detect(Label, "ymTq2"),
  "ymYPET" = str_detect(Label, "ymYPET"),
  .method = "first",
  .default = 5555
))

combined3$Count <- as.numeric(as.character(combined3$Count))
combined3$FP <- as.factor(combined3$FP)

#add statistics
errordata <- combined3 %>% 
  group_by(FP) %>% 
  summarise(
    total_cells = length(FP[Count>=0]),
    cells_with_OSER = length(FP[Count>=1]),
    OSER_per_cell = mean(Count),
    SD_OSER_per_cell = sd(Count),
   low_95CI = ci(Count)[2],
    high_95CI = ci(Count)[3])

errordata$percentage <- errordata$cells_with_OSER/errordata$total_cells

#add sample size per condition
errordata <-
  errordata %>% 
  group_by(FP) %>% 
  mutate(FP_samplesize=paste(FP,", n=",total_cells)) %>% 
  ungroup()
errordata$FP_samplesize <- gsub(" ", "", errordata$FP_samplesize)
errordata$FP_samplesize <- gsub(",n", ", n", errordata$FP_samplesize)
errordata$FP_samplesize <- gsub("as", "as  ", errordata$FP_samplesize)


# one-way anova
# We want to know if there is any significant difference between the different groups
res.aov <- aov(Count ~ FP, data = combined3)
summary(res.aov) #The groups highlighted with "*" in the model summary have significant differences
# Tukey HSD (Tukey Honest Significant Differences, R function: TukeyHSD()) for performing multiple pairwise-comparison between the means of groups
TukeyHSD(res.aov)


plot <- ggplot() + geom_bar(data=errordata, aes(x=FP_samplesize, y=OSER_per_cell, fill=FP_samplesize), stat="identity", position = "dodge", color="black", width=0.85) +  scale_fill_manual(values = c("#dd2c2c", "#FFF000", "#3EC73E", "#dd2c2c" , "#168be5","#FFF000" , "#FFF000", "#dd2c2c")) +   theme_bw() + labs(title = titel, subtitle = ondertitel2)+ theme(plot.title = element_text(hjust = 0.5), plot.subtitle = element_text(hjust = 0.5)) +  labs(x=TextatXaxis,y="OSER structures per cell") + theme(axis.text.x = element_text(angle = 60, hjust = 1)) + theme(legend.position="none")
plot <- plot +  theme( strip.text.x = element_text(size = 16),
                        axis.text = element_text( size = 15 ),
                        axis.text.x = element_text( size = 15 ),
                        axis.title = element_text( size = 15),
                        plot.title = element_text(size=24),
                        plot.subtitle = element_text(size=18),
                        legend.position="none")
plot <- plot + geom_errorbar(data=errordata, aes(x=FP_samplesize, ymin = low_95CI, ymax = high_95CI), width=0.15, size=1)

plot


plot2 <- ggplot() + geom_bar(data=errordata, aes(x=FP_samplesize, y=percentage, fill=FP_samplesize), stat="identity", position = "dodge", color="black", width=0.85) +  scale_fill_manual(values = c("#dd2c2c", "#FFF000", "#3EC73E", "#dd2c2c" , "#168be5","#FFF000" , "#FFF000", "#dd2c2c")) +   theme_bw() + labs(title = titel, subtitle = ondertitel2)+ theme(plot.title = element_text(hjust = 0.5), plot.subtitle = element_text(hjust = 0.5)) +  labs(x=TextatXaxis,y="% cells with OSERs") + theme(axis.text.x = element_text(angle = 60, hjust = 1)) + theme(legend.position="none")
plot2 <- plot2+ theme( strip.text.x = element_text(size = 16),
                       axis.text = element_text( size = 15 ),
                       axis.text.x = element_text( size = 15 ),
                       axis.title = element_text( size = 15),
                       plot.title = element_text(size=24),
                       plot.subtitle = element_text(size=18),
                       legend.position="none")
plot2

